==> commons-rest-0.1.23-sources.jar: ar/com/sdd/commons/rest/util/QueryBuilder.java <==
package ar.com.sdd.commons.rest.util;

import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.Date;

public class QueryBuilder {

    private String path;
    private StringBuilder params;
    private boolean firstParam;
    private SimpleDateFormat sdfDate = new SimpleDateFormat("yyyy-MM-dd");

    private QueryBuilder() {
        path = "";
        params = new StringBuilder();
        firstParam = true;
    }

    public static QueryBuilder Builder() {
        return new QueryBuilder();
    }

    public QueryBuilder path(String path) {
        if (path != null) {
            this.path = path;
        }
        return this;
    }

    public QueryBuilder add(String key, String value) {
        if (key != null && value != null) {
            appendParam(key, value);
        }
        return this;
    }

    public QueryBuilder add(String key, Number value) {
        if (key != null && value != null) {
            appendParam(key, value.toString());
        }
        return this;
    }

    public QueryBuilder add(String key, Date value) {
        if (key != null && value != null) {
            appendParam(key, sdfDate.format(value));
        }
        return this;
    }

    public String build() {
        return path + params.toString();
    }

    private void appendParam(String key, String value) {
        if (firstParam) {
            params.append("?");
            firstParam = false;
        } else {
            params.append("&");
        }
        try {
            params.append(URLEncoder.encode(key, "UTF-8")).append("=").append(URLEncoder.encode(value, "UTF-8"));
        } catch (Exception e) {
            throw new RuntimeException("Encoding incorrecto en key [" + key + "], value [" + value + "]", e);
        }
    }

}

==> commons-rest-0.1.39-sources.jar: ar/com/sdd/commons/rest/util/QueryBuilder.java <==
package ar.com.sdd.commons.rest.util;

import java.net.URLEncoder;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

public class QueryBuilder {

    private String path;
    private StringBuilder params;
    private boolean firstParam;
    private SimpleDateFormat sdfDate = new SimpleDateFormat("yyyy-MM-dd");

    private QueryBuilder() {
        path = "";
        params = new StringBuilder();
        firstParam = true;
    }

    public static QueryBuilder Builder() {
        return new QueryBuilder();
    }

    public QueryBuilder path(String path) {
        if (path != null) {
            this.path = path;
        }
        return this;
    }

    public QueryBuilder add(String key, String value) {
        if (key != null && value != null) {
            appendParam(key, value);
        }
        return this;
    }

    public QueryBuilder add(String key, Number value) {
        if (key != null && value != null) {
            appendParam(key, value.toString());
        }
        return this;
    }

    public QueryBuilder add(String key, List<String> value) {
        if (key != null && value != null) {
            StringBuilder values = new StringBuilder();
            String sep = "";
            values.append("[");
            for (String oneValue : value) {
                values.append(sep).append(oneValue);
                sep = ",";
            }
            values.append("]");
            appendParam(key, values.toString());
        }
        return this;
    }

    public QueryBuilder add(String key, Date value) {
        if (key != null && value != null) {
            appendParam(key, sdfDate.format(value));
        }
        return this;
    }

    public String build() {
        return path + params.toString();
    }

    private void appendParam(String key, String value) {
        if (firstParam) {
            params.append("?");
            firstParam = false;
        } else {
            params.append("&");
        }
        try {
            params.append(URLEncoder.encode(key, "UTF-8")).append("=").append(URLEncoder.encode(value, "UTF-8"));
        } catch (Exception e) {
            throw new RuntimeException("Encoding incorrecto en key [" + key + "], value [" + value + "]", e);
        }
    }

}
